kernel::bsp::device_driver::bcm::bcm2xxx_pl011_uart

Struct PL011UartInner

struct PL011UartInner {
    registers: MMIODerefWrapper<RegisterBlock>,
    chars_written: usize,
    chars_read: usize,
}

Fields

registers: MMIODerefWrapper<RegisterBlock>chars_written: usizechars_read: usize

Implementations

Source

impl PL011UartInner

Create an instance.

Safety

  • The user must ensure to provide a correct MMIO start address.
pub const unsafe fn new(mmio_start_addr: usize) -> Self

pub fn init(&mut self)

Set up baud rate and characteristics.

This result in 8N1 and 921_600 baud.

The calculation for the BRD is (we set the clock to 48 MHz in config.txt): (48_000_000 / 16) / 921_600 = 3.2552083.

This means the integer part is 3 and goes into the IBRD. The fractional part is 0.2552083.

FBRD calculation according to the PL011 Technical Reference Manual: INTEGER((0.2552083 * 64) + 0.5) = 16.

Therefore, the generated baud rate divdier is: 3 + 16/64 = 3.25. Which results in a generated baud rate of 48_000_000 / (16 * 3.25) = 923_077.

Error = ((923_077 - 921_600) / 921_600) * 100 = 0.16%.

fn write_char(&mut self, c: char)

Send a character.

fn flush(&self)

Block execution until the last bufferred character has been physically put on the TX wire.

fn read_char_converting(&mut self, blocking_mode: BlockingMode) -> Option<char>

Retrieve a character.